"micro-gunzip setup module."

def main():

    from setuptools import setup
    from gunzip import Gunzip

    install_requires = ["microapp>=0.1.3"]

    setup(
        name=Gunzip._name_,
        version=Gunzip._version_,
        description=Gunzip._description_,
        long_description=Gunzip._long_description_,
        author=Gunzip._author_,
        author_email=Gunzip._author_email_,
        classifiers=[
            "Development Status :: 3 - Alpha",
            "Intended Audience :: Science/Research",
            "Topic :: Scientific/Engineering",
            "License :: OSI Approved :: MIT License",
            "Programming Language :: Python :: 3",
            "Programming Language :: Python :: 3.5",
            "Programming Language :: Python :: 3.6",
            "Programming Language :: Python :: 3.7",
            "Programming Language :: Python :: 3.8",
        ],
        keywords="microapp gunzip",
        include_package_data=True,
        install_requires=install_requires,
        scripts=["gunzip.py"],
        entry_points={"microapp.apps": "gunzip = gunzip"},
        project_urls={
            "Bug Reports": "https://github.com/grnydawn/micro-gunzip/issues",
            "Source": "https://github.com/grnydawn/micro-gunzip",
        }
    )

if __name__ == '__main__':
    import multiprocessing
    multiprocessing.freeze_support()
    main()



"Microapp gzip module wrapper for uncompressing"

import os
import gzip
import shutil

from typing import Any

from microapp import App


class Gunzip(App):

    _name_ = "gunzip"
    _version_ = "0.1.5"
    _description_ = "Microapp gunzip"
    _long_description_ = "Microapp gunzip"
    _author_ = "Youngsung Kim"
    _author_email_ = "youngsung.kim.act2@gmail.com"
    _url_ = "https://github.com/grnydawn/micro-gunzip"

    def __init__(self, mgr):

        self.add_argument("zipfile", type=str, help="zipped file")
        self.add_argument("-o", "--outfile", type=str, help="file path for a unzipped file")

        self.register_forward("data", type=Any, help="unzipped binary data")

    def perform(self, mgr, args):

        zipfile = args.zipfile["_"]

        with gzip.open(zipfile, 'rb') as f_in:
            if args.outfile:
                with open(args.outfile["_"], 'wb') as f_out:
                    shutil.copyfileobj(f_in, f_out)
            #else:
            #    print(f_in.read())
                #root, ext = os.path.splitext(zipfile)
                #outfile = root if ext == ".gz" else "%s.uncompressed" % zipfile

                #with open(outfile, 'wb') as f_out:
                #    shutil.copyfileobj(f_in, f_out)

            f_in.seek(0)
            self.add_forward(data=f_in.read().decode())
